# encoding: utf-8

import re

from ..auth import need_login
from ..error import ZhihuError
from . import Model
from ..settings import ZHUANLAN_HEADERS
from ..url import URL


class Column(Model):
    """
    专栏
    """

    def __init__(self, slug=None, url=None):
        slug = slug if slug is not None else self._extract_slug(url)
        if not slug:
            raise ZhihuError("没有指定专栏的的slug或者url")
        self.slug = slug
        super(Column, self).__init__(headers=ZHUANLAN_HEADERS)
        self._session.headers["x-xsrf-token"] = self._get_xsrf()

    @staticmethod
    def _extract_slug(url):
        """
        从url中提取目标slug
        """
        pattern = re.compile("https://zhuanlan.zhihu.com/(\w+)/?.*?")
        match = pattern.search(url)
        return match.group(1) if match else None

    def followers(self, limit=500, offset=0, **kwargs):
        """
        用户关注列表
        :param limit: 最大获取条数,不能超过500条
        :param offset: 偏移量
        :return: 返回用户列表
        """
        r = self._session.get(URL.column_followers(self.slug), params={"limit": limit, "offset": offset}, **kwargs)
        return r.json()

    @need_login
    def follow(self, **kwargs):
        """关注某专栏"""
        r = self._execute(method="put", url=URL.follow_column(self.slug), **kwargs)
        if r.ok:
            print("关注专栏成功")
        else:
            raise ZhihuError("操作失败：%s" % r.text)

    @need_login
    def unfollow(self, **kwargs):
        """取消关注某专栏"""
        r = self._execute(method="delete", url=URL.unfollow_column(self.slug), **kwargs)
        if r.ok:
            print("取消关注专栏成功")
        else:
            raise ZhihuError("操作失败：%s" % r.text)
    
    def _get_xsrf(self, **kwargs):
        response = self._session.get(URL.column_index(self.slug), **kwargs)
        return response.cookies['XSRF-TOKEN']


from zhihu.models import answer
from zhihu.models import zhihu
from zhihu.models import question
from zhihu.models import column
from zhihu.models import account

__version__ = '0.0.1'
__author__ = 'liuzhijun'
__license__ = 'MIT'

__all__ = ["Answer", "Zhihu", "Question", "Column", "Account"]

Answer = answer.Answer
Zhihu = zhihu.Zhihu
Question = question.Question
Column = column.Column
Account = account.Account



# encoding: utf-8

import logging
import re

from . import Model
from ..models import RequestDataType
from ..url import URL
from ..error import ZhihuError


class Account(Model):
    def login(self, account, password, **kwargs):
        """
        账户登录
        :param account: email或者手机号码
        :param password:
        :param kwargs:
        :return:
        """
        email_regex = r"(^[a-zA-Z0-9_.+-]+@[a-zA-Z0-9-]+\.[a-zA-Z0-9-.]+$)"
        phone_regex = r"\+?\d{10,15}$"
        email_pattern = re.compile(email_regex)
        phone_pattern = re.compile(phone_regex)

        if email_pattern.match(account):
            return self._login_with_email(account, password, **kwargs)
        elif phone_pattern.match(account):
            return self._login_with_phone(account, password, **kwargs)
        else:
            self.log("无效的用户名", level=logging.ERROR)
            return {"r": 1, "msg": "无效的用户名"}

    def _login_with_phone(self, phone, password, **kwargs):
        data = {
            '_xsrf': self._get_xsrf(),
            'password': password,
            'phone_num': phone,
            "captcha": self._get_captcha(),
            "remeber_me": "true",
        }
        return self._login_execute(url=URL.phone_login(), data=data, **kwargs)

    def _login_with_email(self, email, password, **kwargs):
        data = {'email': email,
                'password': password,
                '_xsrf': self._get_xsrf(**kwargs),
                "captcha": self._get_captcha(**kwargs),
                'remember_me': 'true'}
        return self._login_execute(url=URL.email_login(), data=data, **kwargs)

    def _login_execute(self, url=None, data=None, **kwargs):

        r = super(Account, self)._execute(method="post", url=url, data=data, data_type=RequestDataType.FORM_DATA,
                                          **kwargs)

        if r.ok:
            result = r.json()
            if result.get("r") == 0:
                self.log(result.get("msg"))
                self._session.cookies.save(ignore_discard=True)  # 保存登录信息cookies
                return result
            else:
                self.log(result.get("msg"), level=logging.ERROR)
                return result

        else:
            self.log("登录失败", level=logging.ERROR)
            self.log(r.text)
            return {'r': 1, "msg": "登录失败"}

    def _register_validate(self, data):
        """
        注册前的验证,是否已经注册
        :return:
        """
        r = super(Account, self)._execute(method="post",
                                          url=URL.register_validate(),
                                          data=data,
                                          data_type=RequestDataType.FORM_DATA)
        if r.ok and r.json().get("r") == 0:
            return True
        else:
            if r.ok and r.json().get("r") == 1:
                self.log(r.text)
            return False

    def register(self, name=None, phone_num=None, password=None):
        data = {
            "fullname": name,
            "phone_num": phone_num,
            "password": password,
            "_xsrf": super(Account, self)._get_xsrf(),
            "captcha": super(Account, self)._get_captcha(_type="register"),
            "captcha_source": "register",
        }
        valid = self._register_validate(data)
        if valid:
            self.log("账号验证成功,发送短信验证码")
            params = {"phone_num": phone_num, "captcha_source": "register"}
            # 发送验证码
            r = self._execute(method="get", url=URL.register_sms_code(), params=params)
            self.log(r.json().get("msg"))
            code = input("输入短信验证码:")
            data['verification_code'] = code
            data.pop("captcha")
            r = self._execute(method="post", url=URL.register(), data=data, data_type=RequestDataType.FORM_DATA)
            if r.ok and r.json().get("r") == 0:
                self.log("注册成功")
                return r.json()
            else:
                if r.ok and r.json().get("r") != 0:
                    self.log(r.json().get("msg"), level=logging.ERROR)
                if not r.ok:
                    self.log("请求失败", level=logging.ERROR)
                return r.json()
        else:
            raise ZhihuError("验证失败,请查看日志")



import logging
from zhihu import Answer
from zhihu import Account

account = Account()
# account.login("邮箱地址或者手机号码", "这里是密码")
# account.login("+33752962193", "zhihudetail")

from zhihu import Zhihu

z = Zhihu()
z.user(user_slug="liuzhijun001")


def vote_up_with_id():
    data = Answer(id=14005147).vote_up()
    print(data)


logging.basicConfig(level=logging.INFO)

if __name__ == '__main__':
    # vote_up_with_id()
    from zhihu import Question
    Question(id="60231684").unfollow_question()

    # Zhihu().login("+33752962193", "zhihudetail")
    # model.login("158", "xxxx")

    # from zhihu import Zhihu
    #
    # profile  = Zhihu().user(user_slug="xiaoxiaodouzi")
    # # print(profile)
    #
    # from zhihu import Account
    #
    # account = Account()
    # account.register("续航小三", phone_num="+33752962193", password="zhihudetail")



# encoding: utf-8

import logging
import os
import platform
import re
import subprocess

try:
    from http import cookiejar  # py3
except:
    import cookielib as cookiejar  # py2

try:
    input = raw_input  # py2
except:
    pass

import requests
import requests.packages.urllib3 as urllib3
from bs4 import BeautifulSoup
from ..error import ZhihuError
from ..url import URL
from .. import settings

urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)


class RequestDataType(object):
    """
    发送请求时,传给知乎服务器的数据类型
    有两种请求,1. 表单类型,2 json格式的字符串
    """
    FORM_DATA, JSON_DATA = range(2)


class Model(object):
    def __init__(self, **kwargs):
        self._session = requests.Session()
        self._session.verify = False
        self._session.headers = settings.HEADERS
        self._session.cookies = cookiejar.LWPCookieJar(filename=settings.COOKIES_FILE)
        for k, v in kwargs.items():
            setattr(self._session, k, v)
        try:
            self._session.cookies.load(ignore_discard=True)
        except:
            pass

    @property
    def logger(self):
        logger = logging.getLogger(self.__class__.__name__)
        return logging.LoggerAdapter(logger, {'zhihu': self})

    def log(self, message, level=logging.INFO, **kw):
        self.logger.log(level, message, **kw)

    def _get_captcha(self, _type="login", **kwargs):
        r = self._session.get(URL.captcha(_type=_type), **kwargs)
        with open('captcha.jpg', 'wb') as f:
            f.write(r.content)

        if platform.system() == 'Darwin':
            subprocess.call(['open', 'captcha.jpg'])
        elif platform.system() == 'Linux':
            subprocess.call(['xdg-open', 'captcha.jpg'])
        else:
            os.startfile('captcha.jpg')
        captcha = input("输入验证码：")
        return captcha

    def _get_xsrf(self, url=None, **kwargs):
        """
        获取某个页面下的xsrf
        :param url:
        :param kwargs:
        :return:
        """
        response = self._session.get(url or URL.index(), **kwargs)
        soup = BeautifulSoup(response.content, "html.parser")
        xsrf = soup.find('input', attrs={"name": "_xsrf"}).get("value")
        return xsrf

    def _user_id(self, user_slug):
        """
        user_slug 转 user_id
        :param user_slug:
        :return:
        """
        profile = self.user(user_slug=user_slug)
        user_id = profile.get("id")
        return user_id

    def _user_slug(self, profile_url):
        """
        profile_url 转 user_slug
        :param profile_url:
        :return:
        """
        pattern = re.compile("https?://www.zhihu.com/people/([\w-]+)")
        match = pattern.search(profile_url)
        if match:
            user_slug = match.group(1)
            return user_slug
        else:
            raise ZhihuError("invalid profile url")

    def _execute(self, method="post", url=None, params=None, data=None, data_type=RequestDataType.JSON_DATA, **kwargs):
        """
        通用请求方法
        :param method: 请求方法
        :param url:     请求URL
        :param params:  请求参数
        :param data:    请求数据
        :param data_type:    提交的数据格式(可能是表单类型,也可能是json格式的字符串)
        :param kwargs:  requests支持的参数，比如可以设置代理参数
        :return: response
        """
        if data_type == RequestDataType.JSON_DATA:
            r = getattr(self._session, method)(url, json=data, params=params, **kwargs)
        else:
            r = getattr(self._session, method)(url, data=data, params=params, **kwargs)
        return r



# encoding: utf-8
"""
通用的操作放在此模块中
"""
import logging

from . import Model
from ..auth import need_login
from ..error import ZhihuError
from ..url import URL


class Zhihu(Model):
    @need_login
    def send_message(self, content, user_id=None, profile_url=None, user_slug=None, **kwargs):
        """
        给指定的用户发私信
        :param content 私信内容
        :param user_id 用户id
        :param profile_url: 用户主页地址
        :param user_slug : 用户的个性域名

        >>> send_message(profile_url = "https://www.zhihu.com/people/xiaoxiaodouzi")
        >>> send_message(user_slug = "xiaoxiaodouzi")
        >>> send_message(user_id = "1da75b85900e00adb072e91c56fd9149")
        """
        if not any([user_id, profile_url, user_slug]):
            raise ZhihuError("至少指定一个关键字参数")

        if user_id is None:
            user_slug = self._user_slug(
                profile_url) if user_slug is None else user_slug
            user_id = self._user_id(user_slug)

        data = {"type": "common", "content": content, "receiver_hash": user_id}
        response = self._session.post(URL.message(), json=data, **kwargs)
        if response.ok:
            return response.json()
            self.log("发送成功")
        else:
            self.log("发送失败")
            raise ZhihuError("操作失败：%s" % response.text)

    @need_login
    def user(self, user_slug=None, profile_url=None, **kwargs):
        """
        获取用户信息
        :param user_slug : 用户的个性域名
        :param profile_url: 用户主页地址

        :return:dict

        >>> user(profile_url = "https://www.zhihu.com/people/xiaoxiaodouzi")
        >>> user(user_slug = "xiaoxiaodouzi")

        """
        if not any([profile_url, user_slug]):
            raise ZhihuError("至少指定一个关键字参数")

        user_slug = self._user_slug(profile_url) if user_slug is None else user_slug
        response = self._session.get(URL.profile(user_slug), **kwargs)

        if response.ok:
            return response.json()
        else:
            raise ZhihuError("操作失败：%s" % response.text)

    @need_login
    def follow(self, user_slug=None, profile_url=None, **kwargs):
        """
        关注用户
        :param user_slug:
        :param profile_url:
        :return: {"follower_count": int}

        >>> follow(profile_url = "https://www.zhihu.com/people/xiaoxiaodouzi")
        >>> follow(user_slug = "xiaoxiaodouzi")
        """
        if not any([profile_url, user_slug]):
            raise ZhihuError("至少指定一个关键字参数")

        user_slug = self._user_slug(profile_url) if user_slug is None else user_slug
        response = self._session.post(URL.follow_people(user_slug), **kwargs)
        if response.ok:
            data = response.json()
            data['followed'] = True
            return data
        else:
            raise ZhihuError("操作失败：%s" % response.text)

    @need_login
    def unfollow(self, user_slug=None, profile_url=None, **kwargs):
        """
        取消关注用户
        :param user_slug:
        :param profile_url:
        :return: {"follower_count": int}

        >>> unfollow(profile_url = "https://www.zhihu.com/people/xiaoxiaodouzi")
        >>> unfollow(user_slug = "xiaoxiaodouzi")
        """
        if not any([profile_url, user_slug]):
            raise ZhihuError("至少指定一个关键字参数")

        user_slug = self._user_slug(
            profile_url) if user_slug is None else user_slug
        response = self._session.delete(URL.follow_people(user_slug), **kwargs)
        if response.ok:
            data = response.json()
            data['followed'] = False
            return data
        else:
            raise ZhihuError("操作失败：%s" % response.text)

    @need_login
    def followers(self, user_slug=None, profile_url=None, limit=20, offset=0, **kwargs):
        """
        获取某个用户的粉丝列表
        :param user_slug:
        :param profile_url:
        :param limit: 最大返回数量
        :param offset:游标
        :param kwargs:
        :return:
                {
                    "paging": {
                        "is_end": true,
                        "totals": 1381207,
                        "is_start": false,
                    },
                    "data": [{
                        "avatar_url_template": "https://pic1.zhimg.com/fdbce7544_{size}.jpg",
                        "badge": [],
                        "name": "OPEN",
                        "is_advertiser": false,
                        "url": "http://www.zhihu.com/api/v4/people/0fcb310a722c5bb99d864ace7bb2d89c",
                        "url_token": "open",
                        "user_type": "people",
                        "answer_count": 50,
                        "headline": "上知乎，恍然大悟！",
                        "avatar_url": "https://pic1.zhimg.com/fdbce7544_is.jpg",
                        "is_org": false,
                        "gender": 1,
                        "follower_count": 78,
                        "type": "people",
                        "id": "0fcb310a722c5bb99d864ace7bb2d89c"
                        },
                        ]
                    }
        """
        if not any([profile_url, user_slug]):
            raise ZhihuError("至少指定一个关键字参数")

        user_slug = self._user_slug(
            profile_url) if user_slug is None else user_slug

        r = self._session.get(URL.followers(user_slug),
                              params={"limit": limit, "offset": offset},
                              **kwargs)
        self.log(r.url)
        if r.ok:
            return r.json()
        else:
            self.log("status code %s, body: %s" % (r.status_code, r.text), level=logging.ERROR)
            raise ZhihuError("操作失败：%s" % r.text)



# encoding: utf-8

import re

from ..auth import need_login
from ..error import ZhihuError
from . import Model
from ..url import URL


class Question(Model):
    def __init__(self, id=None, url=None):
        id = id if id is not None else self._extract_id(url)
        if not id:
            raise ZhihuError("没有指定问题的id或者url")
        self.id = str(id)
        super(Question, self).__init__()

    @staticmethod
    def _extract_id(url):
        """
        从url中提取目标id
        """
        pattern = re.compile("https://www.zhihu.com/question/(\d+).*?")
        match = pattern.search(url)
        return match.group(1) if match else None

    # def _execute(self, method="post", url=None, data=None, **kwargs):
    #     super(Question, self)._execute(method=method, url=url, data=data, **kwargs)

    @need_login
    def follow_question(self, **kwargs):
        """关注某问题"""
        r = self._execute(url=URL.follow_question(self.id), **kwargs)
        if r.ok:
            return r.json()
        else:
            raise ZhihuError("操作失败：%s" % r.text)

    @need_login
    def unfollow_question(self, **kwargs):
        """取消关注某问题"""
        r = self._execute(method="delete", url=URL.unfollow_question(self.id), **kwargs)
        if r.ok:
            return {'is_following': False}
        else:
            raise ZhihuError("操作失败：%s" % r.text)



# encoding: utf-8
import os.path
import random

# UserAgent list
user_agent_list = [
    "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_11_3) "
    "AppleWebKit/537.36 (KHTML, like Gecko) Chrome/59.0.3071.115 Safari/537.36"
]

USER_AGENT = random.choice(user_agent_list)

HEADERS = {
    "Host": "www.zhihu.com",
    "Referer": "https://www.zhihu.com/",
    'User-Agent': USER_AGENT
}

ZHUANLAN_HEADERS = {
    "Host": "zhuanlan.zhihu.com",
    "Referer": "https://zhuanlan.zhihu.com/",
    'User-Agent': USER_AGENT
}

# COOKIE 存储位置
COOKIES_FILE = os.path.join(os.path.expanduser('~'), "cookies.txt")



# encoding: utf-8
"""
通用ＵＲＬ类,知乎官方ＵＲＬ接口地址
"""

import time


class URL(object):
    host = "https://www.zhihu.com"
    zhuanlan_host = "https://zhuanlan.zhihu.com"

    # 邮箱登录
    @classmethod
    def email_login(cls):
        return cls.host + "/login/email"

    # 手机登录
    @classmethod
    def phone_login(cls):
        return cls.host + "/login/phone_num"

    # 私信
    @classmethod
    def message(cls):
        return cls.host + "/api/v4/messages"

    # 验证码
    @classmethod
    def captcha(cls, _type="login"):
        return cls.host + "/captcha.gif?r={timestamp}&type={type}".format(timestamp=str(int(time.time() * 1000)),
                                                                          type=_type)

    # 首页
    @classmethod
    def index(cls):
        return cls.host + ""

    # 用户信息
    @classmethod
    def profile(cls, user_slug):
        return cls.host + "/api/v4/members/{user_slug}".format(user_slug=user_slug)

    # 关注用户
    @classmethod
    def follow_people(cls, user_slug):
        return cls.host + "/api/v4/members/{user_slug}/followers".format(user_slug=user_slug)

    # 赞同/反对/中立
    @classmethod
    def vote_up(cls, answer_id):
        return cls.host + "/api/v4/answers/{id}/voters".format(id=answer_id)

    vote_down = vote_neutral = vote_up

    # 某答案下感谢答主/取消感谢
    @classmethod
    def thank(cls, answer_id):
        return cls.host + "/api/v4/answers/{id}/thankers".format(id=answer_id)

    thank_cancel = thank

    # 某答案没有帮助/撤销没有帮助
    @classmethod
    def nothelp(cls, answer_id):
        return cls.host + "/api/v4/answers/{id}/unhelpers".format(id=answer_id)

    nothelp_cancel = nothelp

    # 关注某问题/取消关注某问题
    @classmethod
    def follow_question(cls, question_id):
        return cls.host + "/api/v4/questions/{id}/followers".format(id=question_id)

    unfollow_question = follow_question

    # 专栏
    @classmethod
    def column(cls, slug):
        return "https://zhuanlan.zhihu.com/api/columns/{slug}".format(slug=slug)

    # 专栏主页
    @classmethod
    def column_index(cls, slug):
        return cls.zhuanlan_host + "/{slug}".format(slug=slug)

    # 专栏的关注者
    @classmethod
    def column_followers(cls, slug):
        a = cls.zhuanlan_host + "/api/columns/{slug}/followers".format(slug=slug)
        return a

    # 关注某专栏/取消关注某专栏
    @classmethod
    def follow_column(cls, slug):
        return cls.zhuanlan_host + "/api/columns/{slug}/follow".format(slug=slug)

    unfollow_column = follow_column

    # 注册用的短信验证码
    @classmethod
    def register_sms_code(cls):
        return cls.host + "/send_register_verification_code/sms"

    # 注册验证URL
    @classmethod
    def register_validate(cls):
        return cls.host + "/register/phone_num/validation"

    @classmethod
    def register(cls):
        return cls.host + "/register/phone_num"

    # 粉丝列表URL
    @classmethod
    def followers(cls, user_slug):
        return cls.host + "/api/v4/members/{slug}/followers?include=data[*].answer_count,gender,follower_count," \
                          "badge[?(type=best_answerer)].topics".format(slug=user_slug)



# -*- encoding: UTF-8 -*-
try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup
import io

VERSION = '0.2.3'

with io.open("README.md", encoding='utf-8') as f:
    long_description = f.read()

install_requires = open("requirement.txt").readlines()

setup(
    name="zhihu",  # pip 安装时用的名字
    version=VERSION,  # 当前版本，每次更新上传到pypi都需要修改
    author="liuzhijun",
    author_email="lzjun567@gmail.com",
    url="https://github.com/lzjun567/zhihu-api",
    keyworads="zhihu",
    description="zhihu api from humans",
    long_description=long_description,
    packages=["zhihu"],
    include_package_data=True,
    license='MIT License',
    classifiers=[],
    install_requires=install_requires,
    setup_requires=[
        'pytest-runner',
    ],
    tests_require=[
        "pytest",
    ]
)



# encoding: utf-8

import requests
import requests.utils

from zhihu.models.account import Account

try:
    input = raw_input  # py2
except:
    pass


def need_login(func):
    """
    用户认证装饰器(判断用户是否已经登录)
    """

    def wrapper(self, *args, **kwargs):
        success = False
        if 'z_c0' not in requests.utils.dict_from_cookiejar(self._session.cookies):
            while not success:
                account = input("请输入Email或者手机号码:")
                password = input("请输入密码:")
                success = Account().login(account, password)
            if success:
                self._session.cookies.load(ignore_discard=True)
        return func(self, *args, **kwargs)

    return wrapper



# encoding: utf-8

import re
try:
    from urllib.parse import urlparse
except:
    from urlparse import urlparse
import os
import requests
from bs4 import BeautifulSoup

from ..auth import need_login
from ..error import ZhihuError
from . import Model
from ..url import URL


class Answer(Model):
    def __init__(self, id=None, url=None):
        id = id if id is not None else self._extract_id(url)
        if not id:
            raise ZhihuError("没有指定回答的id或者url")
        self.id = str(id)

        self.url = url
        super(Answer, self).__init__()

    @staticmethod
    def _extract_id(url):
        """
        从url中提取目标id
        """
        pattern = re.compile("https://www.zhihu.com/question/\d+/answer/([\w-]+)")
        match = pattern.search(url)
        return match.group(1) if match else None

    @need_login
    def vote_up(self, **kwargs):
        """
        赞同
        """
        r = self._execute(url=URL.vote_up(self.id), data={"type": "up"}, **kwargs)
        if r.ok:
            return r.json()
        else:
            raise ZhihuError("操作失败：%s" % r.text)

    @need_login
    def vote_down(self, **kwargs):
        """
        反对
        """
        r = self._execute(url=URL.vote_down(self.id), data={"type": "down"}, **kwargs)
        if r.ok:
            return r.json()
        else:
            raise ZhihuError("操作失败：%s" % r.text)

    @need_login
    def vote_neutral(self, **kwargs):
        """
        中立
        """
        r = self._execute(url=URL.vote_neutral(self.id), data={"type": "neutral"}, **kwargs)
        if r.ok:
            return r.json()
        else:
            raise ZhihuError("操作失败：%s" % r.text)

    @need_login
    def thank(self, **kwargs):
        """
        感谢
        """
        r = self._execute(url=URL.thank(self.id), **kwargs)
        if r.ok:
            return r.json()
        else:
            raise ZhihuError("操作失败：%s" % r.text)

    @need_login
    def thank_cancel(self, **kwargs):
        """
        感谢取消
        """
        r = self._execute(method="delete", url=URL.thank_cancel(self.id), **kwargs)
        if r.ok:
            return r.json()
        else:
            raise ZhihuError("操作失败：%s" % r.text)

    @need_login
    def nothelp(self, **kwargs):
        """
        没有帮助
        """
        r = self._execute(url=URL.nothelp(self.id), **kwargs)
        if r.ok:
            return r.json()
        else:
            raise ZhihuError("操作失败：%s" % r.text)

    @need_login
    def nothelp_cancel(self, **kwargs):
        """
        撤销没有帮助
        """
        r = self._execute(method="delete", url=URL.nothelp_cancel(self.id), **kwargs)
        if r.ok:
            return r.json()
        else:
            raise ZhihuError("操作失败：%s" % r.text)

    def images(self, path="."):
        """
        提取回答中的图片
        :param path 保存路径
        """
        assert self.url, "必须指定URL"
        r = self._execute(method='get', url=self.url)
        soup = BeautifulSoup(r.text, 'lxml')
        content_tag = soup.find('div', class_="RichContent-inner")
        images = content_tag.find_all("img")
        result = []
        for i in images:
            url = i['src']
            if url.startswith("http"):
                filename = urlparse(url).path[1:]

                filename = os.path.join(path, filename)
                with open(filename, 'wb') as fd:
                    r = requests.get(url)
                    for chunk in r.iter_content(chunk_size=128):
                        fd.write(chunk)
                result.append(filename)
        return result
